#[repr(i32)]pub enum SvcMessages {
Show 31 variants
SvcServerInfo = 40,
SvcFlattenedSerializer = 41,
SvcClassInfo = 42,
SvcSetPause = 43,
SvcCreateStringTable = 44,
SvcUpdateStringTable = 45,
SvcVoiceInit = 46,
SvcVoiceData = 47,
SvcPrint = 48,
SvcSounds = 49,
SvcSetView = 50,
SvcClearAllStringTables = 51,
SvcCmdKeyValues = 52,
SvcBspDecal = 53,
SvcSplitScreen = 54,
SvcPacketEntities = 55,
SvcPrefetch = 56,
SvcMenu = 57,
SvcGetCvarValue = 58,
SvcStopSound = 59,
SvcPeerList = 60,
SvcPacketReliable = 61,
SvcHltvStatus = 62,
SvcServerSteamId = 63,
SvcFullFrameSplit = 70,
SvcRconServerDetails = 71,
SvcUserMessage = 72,
SvcBroadcastCommand = 74,
SvcHltvFixupOperatorStatus = 75,
SvcUserCmds = 76,
SvcNextMsgPredicted = 77,
}Variants
SvcServerInfo = 40
SvcFlattenedSerializer = 41
SvcClassInfo = 42
SvcSetPause = 43
SvcCreateStringTable = 44
SvcUpdateStringTable = 45
SvcVoiceInit = 46
SvcVoiceData = 47
SvcPrint = 48
SvcSounds = 49
SvcSetView = 50
SvcClearAllStringTables = 51
SvcCmdKeyValues = 52
SvcBspDecal = 53
SvcSplitScreen = 54
SvcPacketEntities = 55
SvcPrefetch = 56
SvcMenu = 57
SvcGetCvarValue = 58
SvcStopSound = 59
SvcPeerList = 60
SvcPacketReliable = 61
SvcHltvStatus = 62
SvcServerSteamId = 63
SvcFullFrameSplit = 70
SvcRconServerDetails = 71
SvcUserMessage = 72
SvcBroadcastCommand = 74
SvcHltvFixupOperatorStatus = 75
SvcUserCmds = 76
SvcNextMsgPredicted = 77
Implementations
Sourceimpl SvcMessages
impl SvcMessages
Sourceimpl SvcMessages
impl SvcMessages
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SvcMessages>
pub fn from_str_name(value: &str) -> Option<SvcMessages>
Creates an enum from field names used in the ProtoBuf definition.