StringTableContainer

Struct StringTableContainer 

pub struct StringTableContainer {
    pub instance_baselines: HashMap<i32, Vec<u8>>,
    /* private fields */
}
Container for all string tables.

Fields

instance_baselines: HashMap<i32, Vec<u8>>

Cached instance baselines: class_id -> baseline data.

Implementations

Source

impl StringTableContainer

pub fn new() -> Self

pub fn handle_create(&mut self, msg: CsvcMsgCreateStringTable) -> Result<bool>

Handle CSVCMsg_CreateStringTable. Returns true if the created table is instancebaseline (caller should refresh baselines).

pub fn handle_update(&mut self, msg: CsvcMsgUpdateStringTable) -> Result<bool>

Handle CSVCMsg_UpdateStringTable. Returns true if the updated table is instancebaseline (caller should refresh baselines).

pub fn do_full_update(&mut self, cmd: CDemoStringTables)

Do a full update from CDemoStringTables (used in full packets).

pub fn update_instance_baselines(&mut self, _class_info: &ClassInfo)

Update instance baselines from the instancebaseline string table.

pub fn find_table(&self, name: &str) -> Option<&StringTable>

Look up a string table by name.

pub fn tables(&self) -> &[StringTable]

Returns a slice of all string tables.